<?php
/**
 * Kids Education custom helper funtions
 *
 * This is the template that includes all the other files for core featured of Kids Education Pro
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

if( ! function_exists( 'kids_education_pro_check_enable_status' ) ):
	/**
	 * Check status of content.
	 *
	 * @since Kids Education Pro 1.0
	 */
  	function kids_education_pro_check_enable_status( $input, $content_enable ){
		 $options = kids_education_pro_get_theme_options();

		 // Content status.
		 $content_status = $options[ $content_enable ];

		 // Get Page ID outside Loop.
		 $query_obj = get_queried_object();
		 $page_id   = null;
	    if ( is_object( $query_obj ) && 'WP_Post' == get_class( $query_obj ) ) {
	    	$page_id = get_queried_object_id();
	    }

		 // Front page displays in Reading Settings.
		 $page_on_front  = get_option( 'page_on_front' );

		 if ( ( ! is_home() && is_front_page() ) && ( 'static-frontpage' === $content_status ) ) {
			$input = true;
		 }
		 else {
			$input = false;
		 }
		 return ( $input );

  	}
endif;
add_filter( 'kids_education_pro_section_status', 'kids_education_pro_check_enable_status', 10, 2 );


if ( ! function_exists( 'kids_education_pro_is_sidebar_enable' ) ) :
	/**
	 * Check if sidebar is enabled in meta box first then in customizer
	 *
	 * @since Kids Education Pro 1.0
	 */
	function kids_education_pro_is_sidebar_enable() {
		$options               = kids_education_pro_get_theme_options();
		$sidebar_position      = $options['sidebar_position'];

		if ( is_home() ) {
			$post_id = get_option( 'page_for_posts' );
		} else {
			$post_id = get_the_id();
		}

		if ( is_archive() && class_exists( 'TP_Education' ) && is_tp_education() ) {
			return false;
		}

		$post_sidebar_position = get_post_meta( get_the_ID(), 'kids-education-pro-sidebar-position', true );

		if ( ( $sidebar_position == 'no-sidebar' && $post_sidebar_position == "" ) || $post_sidebar_position == 'no-sidebar' ) {
			return false;
		} else {
			return true;
		}

	}
endif;


if ( ! function_exists( 'kids_education_pro_is_frontpage_content_enable' ) ) :
	/**
	 * Check home page ( static ) content status.
	 *
	 *.0
	 *
	 * @param bool $status Home page content status.
	 * @return bool Modified home page content status.
	 */
	function kids_education_pro_is_frontpage_content_enable( $status ) {
		if ( is_front_page() ) {
			$options = kids_education_pro_get_theme_options();
			$front_page_content_status = $options['enable_frontpage_content'];
			if ( false === $front_page_content_status ) {
				$status = false;
			}
		}
		return $status;
	}

endif;

add_filter( 'kids_education_pro_filter_frontpage_content_enable', 'kids_education_pro_is_frontpage_content_enable' );


add_action( 'kids_education_pro_simple_breadcrumb', 'kids_education_pro_simple_breadcrumb' , 10 );
if ( ! function_exists( 'kids_education_pro_simple_breadcrumb' ) ) :

	/**
	 * Simple breadcrumb.
	 *
	 *
	 * @param  array $args Arguments
	 */
	function kids_education_pro_simple_breadcrumb( $args = array() ) {

		/**
		 * Add breadcrumb.
		 *
		 */
		$options = kids_education_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}

		$args = array(
			'show_on_front'   => false,
			'show_title'      => true,
			'show_browse'     => false,
		);
		breadcrumb_trail( $args );      

		return;
	}

endif;


add_action( 'kids_education_pro_action_pagination', 'kids_education_pro_pagination', 10 );
if ( ! function_exists( 'kids_education_pro_pagination' ) ) :

	/**
	 * pagination.
	 *
	 * @since Kids Education Pro 1.0
	 */
	function kids_education_pro_pagination() {
		$options = kids_education_pro_get_theme_options();
		if ( true == $options['pagination_enable'] ) {
			$pagination = $options['pagination_type'];
			if ( $pagination == 'default' ) :
				the_posts_navigation();
			elseif ( $pagination == 'numeric' ) :
				the_posts_pagination( array(
				    'mid_size' => 2,
				    'prev_text' => esc_html__( 'Previous', 'kids-education-pro' ),
				    'next_text' => esc_html__( 'Next', 'kids-education-pro' ),
				) );
			endif;
		}
	}

endif;

add_action( 'kids_education_pro_action_post_pagination', 'kids_education_pro_post_pagination', 10 );
if ( ! function_exists( 'kids_education_pro_post_pagination' ) ) :

	/**
	 * post pagination.
	 *
	 * @since Kids Education Pro 1.0
	 */
	function kids_education_pro_post_pagination() {
		$options = kids_education_pro_get_theme_options(); // get theme options

		if( $options['post_navigation_enable'] ){

	        if( 'post_title' == $options['post_navigation_type'] ){
	        	$args = array(
		        	'prev_text'                  => esc_html__( '%title', 'kids-education-pro' ),
	            	'next_text'                  => esc_html__( '%title', 'kids-education-pro' ),
	            	'screen_reader_text' => esc_html__( 'Continue Reading', 'kids-education-pro' ),
	            );
	        } else {
	        	$args = array( 
					'prev_text'          => esc_html__( 'prev post:', 'kids-education-pro' ),
		            'next_text'          => esc_html__( 'next post:', 'kids-education-pro' ),
		            'screen_reader_text' => esc_html__( 'Continue Reading', 'kids-education-pro' ),
		        );
	        }
			the_post_navigation( $args );	
		}

	}
endif;


/**
 * long excerpt
 * 
 * @since Kids Education Pro 1.0
 * @return  long excerpt value
 */
function kids_education_pro_excerpt_length(){
	$options = kids_education_pro_get_theme_options();
	$length = $options['long_excerpt_length'];
	return $length;
}
/**
 * create the custom excerpts callback
 *
 * @since Kids Education Pro 1.0
 * @return  custom excerpts callback
 */
function kids_education_pro_custom_excerpt( $length_callback = '', $more_callback = '' ){
	$post_id = get_the_ID();
	if ( function_exists( $length_callback ) ){
		add_filter( 'excerpt_length', $length_callback );
	}
	$output = get_the_excerpt( $post_id );
	$output = apply_filters( 'wptexturize', $output );
	$output = apply_filters( 'convert_chars', $output );
	$output = $output;
	echo esc_html( $output );
}

// read more
function kids_education_pro_excerpt_more( $more ){
	return '...';
}
add_filter( 'excerpt_more', 'kids_education_pro_excerpt_more' );

/**
 * custom excerpt function
 * 
 * @since Kids Education Pro 1.0
 * @return  no of words to display
 */
function kids_education_pro_trim_content( $length = 40, $post_obj = null ) {
	global $post;
	if ( is_null( $post_obj ) ) {
		$post_obj = $post;
	}

	$length = absint( $length );
	if ( $length < 1 ) {
		$length = 40;
	}

	$source_content = $post_obj->post_content;
	if ( ! empty( $post_obj->post_excerpt ) ) {
		$source_content = $post_obj->post_excerpt;
	}

	$source_content = preg_replace( '`\[[^\]]*\]`', '', $source_content );
	$trimmed_content = wp_trim_words( $source_content, $length, '...' );

   return apply_filters( 'kids_education_pro_trim_content', $trimmed_content );
}


if ( ! function_exists( 'kids_education_pro_custom_content_width' ) ) :

	/**
	 * Custom content width.
	 *
	 * @since Kids Education Pro 1.0
	 */
	function kids_education_pro_custom_content_width() {

		global $content_width;
		$sidebar_position = kids_education_pro_layout();
		switch ( $sidebar_position ) {

		  case 'no-sidebar':
		    $content_width = 1170;
		    break;

		  case 'left-sidebar':
		  case 'right-sidebar':
		    $content_width = 819;
		    break;

		  default:
		    break;
		}
		if ( ! is_active_sidebar( 'sidebar-1' ) ) {
			$content_width = 1170;
		}

	}
endif;
add_action( 'template_redirect', 'kids_education_pro_custom_content_width' );


if ( ! function_exists( 'kids_education_pro_layout' ) ) :
	/**
	 * Check home page layout option
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @return string Kids Educationlayout value
	 */
	function kids_education_pro_layout() {
		$options = kids_education_pro_get_theme_options();

		$sidebar_position = $options['sidebar_position'];
		$sidebar_position = apply_filters( 'kids_education_pro_sidebar_position', $sidebar_position );
		// Check if single and static blog page
		if ( is_singular() || is_home() ) {
			if ( is_home() ) {
				$post_sidebar_position = get_post_meta( get_option( 'page_for_posts' ), 'kids-education-pro-sidebar-position', true );
			} else {
				$post_sidebar_position = get_post_meta( get_the_ID(), 'kids-education-pro-sidebar-position', true );
			}
			if ( isset( $post_sidebar_position ) && ! empty( $post_sidebar_position ) ) {
				$sidebar_position = $post_sidebar_position;
			}
		}
		return $sidebar_position;
	}
endif;

if ( ! function_exists( 'kids_education_pro_get_thumbnail_image' ) ) :
	/**
	 * display post or page thumbnail image
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @return string value
	 */
	function kids_education_pro_get_thumbnail_image() {
		if ( post_password_required() || is_attachment() ) {
		return;
		}

		if ( is_singular() ) {
			global $post;
			$post_id = $post->ID;

			$header_image_meta = get_post_meta( $post_id, 'kids-education-pro-header-image', true );

			if( 'enable' == $header_image_meta ) return; // retun if thumbnail image is used as a header image.
			the_post_thumbnail( 'full', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); 

		} elseif( is_home() ){ ?>
			<a class="post-thumbnail" href="<?php echo esc_url( get_the_permalink() ); ?>" aria-hidden="true">
			<?php 
				if( has_post_thumbnail() ){
					the_post_thumbnail( 'kids-education-pro-blog-images',  array( 'alt' => the_title_attribute( 'echo=0' ) ) );
				} else { 
					echo '<img  src="'. esc_url( get_template_directory_uri() .'/assets/uploads/no-featured-image-175x230.jpg') .'" alt="'. get_the_title() .'">';
				}
			?>
			</a>
			<?php

		} elseif( is_archive() || is_search() ){ ?>

			<a class="post-thumbnail" href="<?php echo esc_url( get_the_permalink() ); ?>" aria-hidden="true">
			<?php 
				if( has_post_thumbnail() ){
					the_post_thumbnail( 'kids-education-pro-archive-search-image',  array( 'alt' => the_title_attribute( 'echo=0' ) ) );
				}else {
					echo '<img  src="'. esc_url( get_template_directory_uri() .'/assets/uploads/no-featured-image-350x265.jpg') .'" alt="'. get_the_title() .'">';
				}
			?>
			</a>
		<?php

		}
		else { ?>
			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
				<?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			</a>
		<?php } 
	}
endif;
/*
 * Function to get author profile
 */           
function kids_education_pro_get_author_profile(){
	$user_url = get_the_author_meta( 'user_url' );
    $author_url = !empty( $user_url ) ? get_the_author_meta( 'user_url' ) : '#' ;
    ?>
    <div class="about-author">
        <div class="author-image">
          	<?php echo get_avatar( get_the_author_meta( 'ID' ), 150 );  ?>
        </div><!-- .author-image -->
        <div class="author-content">
          	<div class="author-name clear">
             	<h6><?php the_author_posts_link(); ?></h6>
          	</div><!-- .author-name -->
         	<?php 
         	$author_desc =  get_the_author_meta( 'description');
         	if( !empty( $author_desc ) ) : ?>
        	<p><?php the_author_meta( 'description'); ?></p>
        	<?php endif; ?>
        </div><!-- .author-content -->
    </div><!-- .about-author -->
<?php
}
add_action( 'kids_education_pro_author_profile', 'kids_education_pro_get_author_profile' );


/*
 * Function to get related posts
 */           
function kids_education_pro_get_related_posts(){
    global $post;

    $options = kids_education_pro_get_theme_options(); // get theme options

    $post_categories = get_the_category( $post->ID ); // get category object
    $category_ids = array(); // set an empty array

    foreach ( $post_categories as $post_category ) {
      $category_ids[] = $post_category->term_id;
    }

    if( empty( $category_ids ) ) return;

    $qargs = array(
            'posts_per_page'  => 2,
            'category__in'    => $category_ids,
            'post__not_in'    => array( $post->ID ),
            'order'           => 'ASC',
            'orderby'         => 'rand'
        );

    $related_posts = get_posts( $qargs ); // custom posts
    ?>
    	 	<div id="related-posts" class="two-columns">
          <h2 class="related-post-title"><?php esc_html_e( 'Related posts', 'kids-education-pro' ); ?></h2>

          <?php foreach ($related_posts as $related_post ) :

            if ( has_post_thumbnail( $related_post->ID ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $related_post->ID ), 'kids-education-pro-related-posts-image' );
            } else {
                $img_array = array( get_template_directory_uri() . '/assets/uploads/no-featured-image-400x200.jpg' );
            }

			$post_title     = get_the_title( $related_post->ID );
			$post_url       = get_permalink( $related_post->ID );
			$post_date      = get_the_date( '', $related_post->ID);
			$post_content   = kids_education_pro_trim_content( 20, $related_post );
			$post_date_gmt  = $related_post->post_date_gmt;
			$comment_number =  get_comments_number( $related_post->ID );

			$year  = get_the_time('Y', $related_post->ID );
            $month = get_the_time('m', $related_post->ID );
            $day   = get_the_time('d', $related_post->ID );


        	?>

          <article id="post-<?php the_ID(); ?>" class="column-wrapper <?php post_class(); ?>">
            <div class="blog-post-wrap">
               <a class="post-thumbnail" href="<?php echo esc_url( $post_url ); ?>" aria-hidden="true">
                  <img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_html( $post_title ); ?>">  
               </a><!-- .post-thumbnail -->

              <header class="entry-header">
                <h2 class="entry-title"><a href="<?php echo esc_url( $post_url ) ?>" rel="bookmark"><?php echo esc_html(  $post_title ); ?></a></h2> 
                <p class="entry-meta">
                  <span class="posted-on"><span class="screen-reader-text"><?php esc_html_e( 'Posted on', 'kids-education-pro'); ?></span>
                    <a href="<?php echo esc_url( get_day_link( $year, $month, $day ) ); ?>">
                      <time class="entry-date published" datetime="<?php echo esc_attr( $post_date_gmt );?>"><?php echo esc_html( $post_date ); ?></time>
                      <time class="updated" datetime="<?php echo esc_attr( $post_date_gmt );?>"><?php echo esc_html( $post_date ); ?></time>
                    </a>
                  </span><!-- .posted-on -->

                 <?php 
                 	if( function_exists( 'tp_education_like_button') ) :
                 		$likes = tp_education_like_button( $related_post->ID );
                 		echo $likes;
                 	endif;
                ?>

                  <span class="comments-links">
                    <span class="screen-reader-text"><?php esc_html_e( 'Comments', 'kids-education-pro'); ?></span> 
                    <span class="comments-number"><?php echo absint( $comment_number ); ?></span>
                  </span> 
                </p><!-- .entry-meta -->
              </header><!-- .entry-header -->

              <div class="entry-content">
                <p><?php echo esc_html( $post_content ); ?></p> 
                <a href="<?php echo esc_url( $post_url ); ?>" class="read-more"><?php esc_html_e( 'Read More','kids-education-pro'); ?><i class="fa fa-angle-right"></i></a>
              </div><!-- .entry-content -->
            </div><!-- .blog-post-wrap -->
          </article><!-- #post -->
          <?php endforeach; ?>
        </div><!-- .two-columns -->

<?php   
}
add_action( 'kids_education_pro_related_posts', 'kids_education_pro_get_related_posts' );

add_action( 'wp_enqueue_scripts', 'kids_education_pro_script_enqueuer' );
if ( ! function_exists( 'kids_education_pro_script_enqueuer' ) ) :
	/**
	 * enque scripts for ajax
	 *
	 * @since Kids Education Pro 1.0
	 */
	function kids_education_pro_script_enqueuer() {
	   wp_register_script( 'kids_education_pro_script', get_template_directory_uri().'/assets/js/ajax.min.js', array('jquery') );
	   wp_localize_script( 'kids_education_pro_script', 'kids_education_pro', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ));        
	   wp_enqueue_script( 'kids_education_pro_script' );   
	}
endif;

add_action("wp_ajax_kids_education_pro_ajax_handler", "kids_education_pro_ajax_handler");
add_action("wp_ajax_nopriv_kids_education_pro_ajax_handler", "kids_education_pro_ajax_handler");

if ( ! function_exists( 'kids_education_pro_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since Kids Educaton Pro 1.0
	 */
	function kids_education_pro_ajax_handler(){
		$options = kids_education_pro_get_theme_options();
		
		$portfolio_ids =  !empty( $options['portfolio_category'] ) ? $options['portfolio_category'] : array();

		$posts_per_page = get_option( 'posts_per_page', 8 );

	    $page = (isset($_POST['pageNumber'])) ? $_POST['pageNumber'] : 1;

	    header("Content-Type: text/html");

	    $args = array(
	        'post_type' 		=> 'post',
	        'posts_per_page' 	=> absint( $posts_per_page ),
	        'category__in'      => $portfolio_ids,
	        'paged'    			=> $page,
	    );

        $portfolio_posts = get_posts( $args ); 

        foreach ( $portfolio_posts as $key => $portfolio_post ) {
           $portfolio_post_id = $portfolio_post->ID; // get post id 
           $portfolio_categories =  get_the_category( $portfolio_post_id ); // get post categories

           $term_slug = ''; 
           foreach ( $portfolio_categories as $key => $portfolio_category ) {
                $term_slug .= $portfolio_category->slug . ' ';
           }
     	?>
            <div class="portfolio-item activities <?php echo esc_attr( $term_slug ); ?>">
                <div class="image-wrapper">
                    <?php if( has_post_thumbnail( $portfolio_post_id ) ){
                        $img_array  = wp_get_attachment_image_src( get_post_thumbnail_id( $portfolio_post_id ), 'kids-education-pro-gallery-section-small' );
                        $img_array_large = wp_get_attachment_image_src( get_post_thumbnail_id( $portfolio_post_id ), 'large' );
                    } else {
                        $img_array[0]       =  get_template_directory_uri().'/assets/uploads/no-featured-image-300x300.png';
                        $img_array_large[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-625x400.png';
                    } ?>
                    <img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_html( get_the_title( $portfolio_post_id ) ); ?>">
                    <div class="blue-overlay"></div>
                </div><!-- .image-wrapper -->
                <div class="hovercontent">
                    <a data-title="Gallery" href="<?php echo esc_url( $img_array_large[0] ) ?>" data-lightbox="masonry"><i class="fa fa-search"></i></a>
                    <a href="<?php echo esc_url( get_permalink( $portfolio_post_id ) );?>"><i class="fa fa-link"></i></a>
                    <p><a href="<?php echo esc_url( get_permalink( $portfolio_post_id ) );?>"><?php echo esc_html( get_the_title( $portfolio_post_id ) );?></a></p>
                </div><!-- end .hover-content -->
            </div><!-- end .portfolio-item -->
            <?php }
	    die();
	}
endif;

if ( ! function_exists( 'kids_education_pro_header_image_meta_option' ) ) :
	/**
	 * Check header image option meta
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @return string Header image meta option
	 */
	function kids_education_pro_header_image_meta_option() {
		
		global $post;

		if ( is_object( $post ) ) {
			$post_id = $post->ID;
			$header_image_meta = get_post_meta( $post_id, 'kids-education-pro-header-image', true );

			if ( 'enable' == $header_image_meta && has_post_thumbnail( $post_id ) ) {
				return wp_get_attachment_url( get_post_thumbnail_id( $post_id ) );
			}elseif ( '' == $header_image_meta && get_header_image() ) {
				return get_header_image();
			} elseif ( 'disable' == $header_image_meta ) {
				return '';
			}
		} else {
			return get_header_image();
		}
	}
endif;

if ( ! function_exists( 'kids_education_pro_check_top_section' ) ) :
	/**
	 * Check if section is top section
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @return string padding-top
	 */
	function kids_education_pro_check_top_section() {
		
		$options = kids_education_pro_get_theme_options(); // get theme options

		$sections_enable_id = array( 'enable_main_slider', 'enable_info_content', 'features_enable', 'search_course_enable', 'recent_enable', 'counter_enable', 'team_enable', 'gallery_enable', 'testimonial_enable', 'category_blog_enable' );

		foreach ($sections_enable_id as $key ) {
			$section_enabled =  apply_filters( 'kids_education_pro_section_status', true, $key );

    		if ( true !== $section_enabled ) {
      			return  'padding-top';
    		}
    		return '';
		}
	}
endif;

if ( ! function_exists( 'kids_education_pro_search_course_no_margin_top' ) ) :
	/**
	 * Check if section below search course is disabled
	 *
	 * @since Kids Education Pro 1.0
	 *
	 * @return string no-margin-top
	 */
	function kids_education_pro_search_course_no_margin_top() {
		
		$options = kids_education_pro_get_theme_options(); // get theme options

		$sections_enable_id = array( 'recent_enable', 'counter_enable', 'team_enable', 'gallery_enable', 'testimonial_enable' );

		foreach ($sections_enable_id as $key ) {
			$section_enabled =  apply_filters( 'kids_education_pro_section_status', true, $key );

    		if ( true !== $section_enabled ) {
      			return  'no-margin-top';
    		}
    		return '';
		}
	}
endif;

if ( ! function_exists( 'kids_education_pro_blog_pre_post' ) ) :
	/**
	 * Pre get posts for blog page
	 *
	 * @since Kids Education Pro 1.0
	 */
	function kids_education_pro_blog_pre_post( $query ) {
		
		$options = kids_education_pro_get_theme_options(); // get theme options
		$exclude_category = ! empty( $options['blog_exclude_category'] ) ? ( array ) $options['blog_exclude_category'] : array();

		if ( is_home() ){
			$query->set( 'category__not_in', $exclude_category );
		}
		
	}
endif;
add_action( 'pre_get_posts', 'kids_education_pro_blog_pre_post' );
