<?php
/**
 * features section
 *
 * This is the template for the content of features section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_features_section' ) ) :
  /**
   * Add features section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_features_section() {

    // Check if features is enabled on frontpage
    $features_enable = apply_filters( 'kids_education_pro_section_status', true, 'features_enable' );
    if ( true !== $features_enable ) {
      return false;
    }

    // Get features section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_features_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render features section now.
    kids_education_pro_render_features_section( $section_details );
  }
endif;
add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_features_section', 30 );


if ( ! function_exists( 'kids_education_pro_get_features_section_details' ) ) :
  /**
   * features section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input features section details.
   */
  function kids_education_pro_get_features_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();

    // features type
    $features_content_type  = $options['features_section_type'];

    $content = array();
    switch ( $features_content_type ) {
      case 'demo':
        $font_icons      = array( 'fa-heart', 'fa-music', 'fa-plane', 'fa-user' );
        $features_title  = array( 
          esc_html__( 'Meal Provided', 'kids-education-pro' ), 
          esc_html__( 'Music Classes', 'kids-education-pro' ), 
          esc_html__( 'Playing Science', 'kids-education-pro' ), 
          esc_html__( 'Swimming', 'kids-education-pro' ) 
        );
        $content_layout  = !empty( $options['features_section_layout'] ) ? $options['features_section_layout'] : 'four-columns'; // check features content layout
        $no_of_demo_post = ( 'three-columns' == $content_layout ) ? 3 : 4; 

        for ( $i=0; $i<$no_of_demo_post; $i++ ) {
          $content[$i]['icon']    = $font_icons[$i];
          $content[$i]['title']   = $features_title[$i];
          $content[$i]['excerpt'] = esc_html__( 'Duis tincidunt lectus eget sem lobortis pellentesque vitae ac augue tibulum pharetra libero cidunt lectus eget sut..', 'kids-education-pro' );
          $content[$i]['url']     = '#';
        }
      break;

      case 'page':
        $ids = array();

        for ( $i = 1; $i <= $options['features_count']; $i++ ) {
            $id = null;
            if ( ! empty( $options[ 'features_page_id_'.$i ] ) ) {
                $id = $options[ 'features_page_id_'.$i ];
            }
            if ( ! empty( $id ) ) {
                $ids[] = absint( $id );
            }
        }

        // Bail if no valid pages are selected.
        if ( empty( $ids ) ) {
            return $input;
        }

        $args = array(
            'post_type'      => 'page',
            'post__in'       => $ids,
            'orderby'        => 'post__in',
            'order'          => 'ASC',
            'posts_per_page'  => absint( $options['features_count'] ),
        );
      break;

      case 'category':
        $cat_id = '';
        if ( !empty( $options['features_dropdown_categories'] ) ) {
            $cat_id = $options['features_dropdown_categories'];
        }

        // Bail if no valid pages are selected.
        if ( empty( $cat_id ) ) {
            return $input;
        }
        $args = array(
            'no_found_rows'  => true,
            'cat'            => $cat_id,
            'post_type'      => 'post',
            'posts_per_page'  => absint( $options['features_count'] ),
            'orderby'        => 'ASC',
        );
      break;

      default:
      break;
    }


    if ( 'demo' != $features_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
            $page_id = $post->ID;

            $content[$i]['url']     = get_permalink( $page_id );
            $content[$i]['title']   = get_the_title( $page_id );
            $content[$i]['excerpt'] = kids_education_pro_trim_content( 15, $post  );
            $content[$i]['icon']    = !empty( $options['features_icon_'.$i ] ) ? $options['features_icon_'.$i ] : '';

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// features section content details.
add_filter( 'kids_education_pro_filter_features_section_details', 'kids_education_pro_get_features_section_details' );


if ( ! function_exists( 'kids_education_pro_render_features_section' ) ) :
  /**
   * Start features section
   *
   * @return string features content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_features_section( $content_details = array() ) {
        $options              = kids_education_pro_get_theme_options();
        $features_title       = !empty( $options['features_section_title'] ) ?  $options['features_section_title'] : '';
        $features_description = !empty( $options['features_section_description'] ) ? $options['features_section_description'] : '';
        $features_layout =  !empty( $options['features_section_layout'] ) ? $options['features_section_layout'] : 'four-columns';

        $background_property = $options['features_background_property'];
        $background_css      = !empty( $options['features_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['features_background_image'] ) .')"' : '';

        if( 'background_color' == $background_property ){
          $background_css = !empty( $options['features_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['features_background_color'] ) .'"' : '';
        }

        if ( empty( $content_details ) ) {
          return;
        } ?>
        <section id="features" class="page-section os-animation" data-os-animation="fadeInUp" <?php echo $background_css;?>>
	        <div class="container">
	          	<header class="entry-header">
	          	<?php if( $features_title ){ ?>
	            	<h2 class="entry-title"><?php echo esc_html( $features_title );?></h2>
	          	<?php } 
	            	if( !empty( $features_description ) ){  ?>
	              	<p class="sub-title"><?php echo esc_html( $features_description ); ?></p>
	          	<?php } ?>
	          	</header><!-- .entry-header -->

	          	<div class="entry-content <?php echo esc_attr( $features_layout ); ?>">

			        <?php foreach ($content_details as $content_detail ) : ?>
			            <div class="column-wrapper">
                            <div class="featured-item">
    			            <?php if( !empty( $content_detail['icon'] ) ){ ?>
    			              	<div class="icon-container">
    			                	<i class="fa <?php echo esc_attr( $content_detail['icon'] ); ?>"></i>
    			              	</div><!-- .icon-container -->
    			              	<?php } ?>
    			              	<h5 class="title"><a href="<?php echo esc_url( $content_detail['url'] );?>"><?php echo esc_html( $content_detail['title'] );?></a></h5>
    				            <?php if( !empty( $content_detail['excerpt'] ) ){ ?>
                                    <p><a href="<?php echo esc_url( $content_detail['url'] );?>"> <?php echo esc_html( $content_detail['excerpt'] ); ?> </a></p>
    				                
    				          <?php  } ?>    
                            </div><!-- .featured-item -->          
			            </div><!-- .column-wrapper -->
			        <?php endforeach; ?>

	          	</div><!-- .entry-content -->
	        </div><!-- .container -->
      	</section><!-- #features -->
      	
<?php 
    }
endif;