<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */
if ( ! function_exists( 'kids_education_pro_add_team_section' ) ) :
  /**
   * Add team section
   *
   *@since Kids Education Pro 1.0
   */
  function kids_education_pro_add_team_section() {

    // Check if team is enabled on frontpage
    $team_enable = apply_filters( 'kids_education_pro_section_status', true, 'team_enable' );
    if ( true !== $team_enable ) {
      return false;
    }

    // Get team section details
    $section_details = array();
    $section_details = apply_filters( 'kids_education_pro_filter_team_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render team section now.
    kids_education_pro_render_team_section( $section_details );
  }
endif;
add_action( 'kids_education_pro_primary_content', 'kids_education_pro_add_team_section', 70 );


if ( ! function_exists( 'kids_education_pro_get_team_section_details' ) ) :
  /**
   * team section details.
   *
   * @since Kids Education Pro 1.0
   * @param array $input team section details.
   */
  function kids_education_pro_get_team_section_details( $input ) {
    $options = kids_education_pro_get_theme_options();

    // team type
    $team_content_type  = $options['team_content_type'];
    $no_of_posts        = $options['team_count'];

    $content = array();
    switch ( $team_content_type ) {
      case 'demo':
        $team_name = array( 
          1 => esc_html__( 'Sarah Smith', 'kids-education-pro' ), 
          2 => esc_html__( 'Robin Leroy Smith', 'kids-education-pro' ),
          3 => esc_html__( 'Suzanne Bar', 'kids-education-pro' ),
          4 => esc_html__( 'Sarah Smith', 'kids-education-pro' ),
        );
        $team_post = array( 
          1 => esc_html__( 'Vice Principal', 'kids-education-pro' ), 
          2 => esc_html__( 'Art & Music Teacher', 'kids-education-pro' ), 
          3 => esc_html__( 'Pre School Teacher', 'kids-education-pro' ), 
          4 => esc_html__( 'Math Teacher', 'kids-education-pro' ), 
        );
        for ( $i=1; $i<=$no_of_posts; $i++ ) {
          $content[ $i ]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/teacher-0'.$i.'.png';
          $content[$i]['url']          = '#';
          $content[$i]['title']        = $team_name[$i];
          $content[$i]['alt']          = esc_html__( 'team Image', 'kids-education-pro' );
          $content[$i]['post']         = $team_post[$i];
        }
      break;

      case 'post':
          $post_list = array();
            for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                $post_id    = ! empty ( $options['team_post_' . $i] ) ? absint( $options['team_post_' . $i] ) : '';
                $post_list  = array_merge( $post_list, array( $post_id ) );
            }
          $args = array(
            'post_type'      => 'tp-team',
            'post__in'       => $post_list, 
            'posts_per_page' => absint( $no_of_posts ),
            'orderby'        => 'post__in',
        );
      break;

      case 'category':
        $cat_id = '';
        if ( !empty( $options['team_category'] ) ) {
            $cat_id = $options['team_category'];
        }

        // Bail if no valid pages are selected.
        if ( empty( $cat_id ) ) {
            return $input;
        }else{
            $cat_id = absint( $cat_id );
        }

        $args = array(
            'terms'          => $cat_id,
            'post_type'      => 'tp-team',
            'posts_per_page' => absint( $no_of_posts ),
        );
      break;

      default:
      break;
    }

    if ( 'demo' != $team_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'large' );
            } 

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $content[$i]['url']      = get_permalink( $page_id );
            $content[$i]['title']    = get_the_title( $page_id );
            $content[$i]['post']     = get_post_meta( $page_id, 'tp_team_designation_value', true );
            $content[$i]['alt']      = get_the_title( $page_id );

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// team section content details.
add_filter( 'kids_education_pro_filter_team_section_details', 'kids_education_pro_get_team_section_details' );


if ( ! function_exists( 'kids_education_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Kids Education Pro 1.0
   *
   */
   function kids_education_pro_render_team_section( $content_details = array() ) {
        $options          = kids_education_pro_get_theme_options();
        $team_title       = $options['team_title'];
        $team_description = $options['team_description'];

        $background_property = $options['team_background_property'];
        $background_css      = !empty( $options['team_background_image'] ) ? 'style="background-image:url('.  esc_url( $options['team_background_image'] ) .')"' : '';

        if( 'background_color' == $background_property ){
          $background_css = !empty( $options['team_background_color'] ) ? 'style="background-color:'.  esc_attr( $options['team_background_color'] ) .'"' : '';
        }

        $section_class = ( 'disabled' == $options['counter_enable'] ) ? 'section-pull-up' : '';

        if ( empty( $content_details ) ) {
          return;
        } ?>
         <section id="team-members" class="page-section move-section-up no-padding-bottom background-image-properties os-animation <?php echo esc_attr( $section_class ); ?>" data-os-animation="fadeIn" <?php echo $background_css; ?>>

          <div class="container">
          <header class="entry-header">
            <?php if ( ! empty( $team_title ) ) : ?>
              <h2 class="entry-title"><?php echo esc_html( $team_title ); ?></h2>
            <?php endif; 
            if ( ! empty( $team_description ) ) :?>
                <p class="sub-title"><?php echo esc_html( strip_tags( htmlspecialchars_decode( $team_description ) ) ); ?></p>
          <?php endif; ?>
          </header><!-- .entry-header -->

          <div class="entry-content four-columns text-center">

          <?php foreach ( $content_details as $content_detail ) :?>
            <div class="column-wrapper">
              <h5 class="member-name">
                <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a>
            </h5>
              <?php if ( ! empty( $content_detail['post'] ) ) : ?>
                <span class="member-position"><?php echo esc_html( $content_detail['post'] ); ?></span>
              <?php endif; ?>
              <div class="team-img">
                <a href="<?php echo esc_url( $content_detail['url'] ); ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content_detail['alt'] ); ?>"></a>
                <div class="hover-content">
                  <h6><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php esc_html_e( 'See Profile', 'kids-education-pro' ); ?></a></h6>
                </div><!-- .hover-content -->
              </div><!-- .team-img -->
            </div><!-- .column-wrapper -->
        <?php endforeach; ?>
            

          </div><!-- .entry-content -->
        </div><!-- .container -->
      </section><!-- #team-members -->
<?php 
    }
endif;